==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/sound/translations/sound_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Suono</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifiche</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Use sounds</source>
        <translation>Usa suoni</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Thema di suoni</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Percorso per suoni</translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundActions</name>
    <message>
        <source>Play Sounds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/sound/translations/sound_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Suono</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifiche</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Thema di suoni</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Percorso per suoni</translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable sound notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundBuddyConfigurationWidget</name>
    <message>
        <source>Use custom sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished">Suono</translation>
    </message>
</context>
<context>
    <name>SoundChatConfigurationWidget</name>
    <message>
        <source>Sound</source>
        <translation type="unfinished">Suono</translation>
    </message>
    <message>
        <source>Use custom sound</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundMuteAction</name>
    <message>
        <source>Play Sounds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
